import Layout from '@/components/layout'
import viewerRoutes from '@/modules/viewer/routes.js'

// 考证课程
const courseRoutes = [
  { path: '/course', redirect: '/course/learn' },
  // 课程学习列表
  { path: '/course/learn', component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/course/learn') },
  // 课程学习详情
  {
    path: '/course/learn/:id',
    name: 'courseLearnItem',
    component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/course/learn/item')
  },
  {
    path: '/course/learn/:courseId/:chapterId',
    name: 'courseLearnChapter',
    component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/course/learn/item')
  },
  // 课程练习列表
  { path: '/course/test', component: () => import(/* webpackChunkName: "course-test" */ '@/pages/course/test') },
  // 课程练习详情
  {
    path: '/course/test/:id',
    name: 'courseTestItem',
    component: () => import(/* webpackChunkName: "course-test" */ '@/pages/course/test/item')
  }
]
const examAnswer = [
  /* 考前摸底 */
  {
    path: '/testExam',
    component: () => import(/* webpackChunkName: "exam" */ '@/pages/testExam')
  },
  /* 考前摸底结果页 */
  {
    path: '/testExam/result',
    component: () => import(/* webpackChunkName: "exam" */ '@/pages/testExam/exam/result')
  },
  /* 真题实战 */
  {
    path: '/mock',
    component: () => import(/* webpackChunkName: "exam" */ '@/pages/mockExam')
  },
  /* 真题实战结果页 */
  {
    path: '/mock/result',
    component: () => import(/* webpackChunkName: "exam" */ '@/pages/mockExam/exam/result')
  }
]

export default [
  { path: '*', redirect: '/index' },
  { path: '/', redirect: '/index' },
  {
    path: '/',
    component: Layout,
    children: [
      /* 首页 */
      { path: '/index', component: () => import(/* webpackChunkName: "feedback" */ '@/pages/home') },
      /* 意见反馈 */
      { path: '/feedback', component: () => import(/* webpackChunkName: "feedback" */ '@/pages/feedback') },
      /* 联系客服 */
      { path: '/contact', component: () => import(/* webpackChunkName: "contact" */ '@/pages/contact') },
      /* 通知 */
      { path: '/messages', component: () => import(/* webpackChunkName: "messages" */ '@/pages/messages') },
      /* 修改密码 */
      {
        path: '/account/password',
        component: () => import(/* webpackChunkName: "account" */ '@/pages/account/password')
      },
      {
        path: '/my/questions/wrong',
        component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/my/questions/questionWrong')
      },
      {
        path: '/my/questions/collection',
        component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/my/questions/questionCollection')
      },
      /* 考证课程 */
      ...courseRoutes,
      ...examAnswer
    ]
  },
  // 课程知识点详情
  {
    path: '/course/learn/:courseId/tag/:id',
    component: () => import(/* webpackChunkName: "course-lear-tag" */ '@/pages/course/learn/components/TagLayout'),
    children: [
      {
        path: '',
        name: 'courseTagItem',
        component: () => import(/* webpackChunkName: "course-lear-tag" */ '@/pages/course/learn/tag')
      }
    ]
  },
  /* 搜索 */
  {
    path: '/search',
    component: Layout,
    props: { showAside: false },
    children: [{ path: '', component: () => import(/* webpackChunkName: "search" */ '@/pages/search') }]
  },
  /* 我的 */
  {
    path: '/my',
    component: () => import('@/pages/my/layout'),
    redirect: '/my/course',
    children: [
      { path: 'course', component: () => import(/* webpackChunkName: "my" */ '@/pages/my/course') },
      { path: 'questions', component: () => import(/* webpackChunkName: "my" */ '@/pages/my/questions/questionAll') }
    ]
  },
  /* 考前摸底考试 */
  {
    path: '/testExam/exam',
    component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/testExam/exam/index')
  },
  /* 模拟考试 */
  {
    path: '/mock/exam',
    component: () => import(/* webpackChunkName: "course-learn" */ '@/pages/mockExam/exam/index')
  },
  ...viewerRoutes
]
